@@ -1,4 +1,5 @@
 #!perl
+# vim: softtabstop=4 tabstop=4 shiftwidth=4 ft=perl expandtab smarttab
 # PODNAME: RT::Client::REST::Attachment
 # ABSTRACT: attachment object representation.
 
@@ -6,11 +7,11 @@ use strict;
 use warnings;
 
 package RT::Client::REST::Attachment;
-$RT::Client::REST::Attachment::VERSION = '0.59';
-use base 'RT::Client::REST::Object';
+$RT::Client::REST::Attachment::VERSION = '0.70';
+use parent 'RT::Client::REST::Object';
 
 use Params::Validate qw(:types);
-use RT::Client::REST::Object::Exception 0.03;
+use RT::Client::REST::Object::Exception;
 
 sub _attributes {{
     id  => {
@@ -45,7 +46,7 @@ sub _attributes {{
         validation  => {
             type    => SCALAR,
         },
-        rest_name   => "ContentType",
+        rest_name   => 'ContentType',
     },
 
     file_name => {
@@ -157,7 +158,7 @@ RT::Client::REST::Attachment - attachment object representation.
 
 =head1 VERSION
 
-version 0.59
+version 0.70
 
 =head1 SYNOPSIS
 
@@ -286,11 +287,11 @@ L<RT::Client::REST::SearchResult>.
 
 =head1 AUTHOR
 
-Dmitri Tikhonov
+Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018 by Dmitri Tikhonov.
+This software is copyright (c) 2022, 2020 by Dmitri Tikhonov.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
