@@ -5,8 +5,8 @@ use strict;
 use warnings;
 
 package RT::Client::REST::Object::Exception;
-$RT::Client::REST::Object::Exception::VERSION = '0.59';
-use base qw(RT::Client::REST::Exception);
+$RT::Client::REST::Object::Exception::VERSION = '0.70';
+use parent qw(RT::Client::REST::Exception);
 
 use RT::Client::REST::Exception (
     'RT::Client::REST::Object::OddNumberOfArgumentsException'   => {
@@ -65,15 +65,15 @@ RT::Client::REST::Object::Exception
 
 =head1 VERSION
 
-version 0.59
+version 0.70
 
 =head1 AUTHOR
 
-Dmitri Tikhonov
+Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018 by Dmitri Tikhonov.
+This software is copyright (c) 2022, 2020 by Dmitri Tikhonov.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
