@@ -6,11 +6,11 @@ use strict;
 use warnings;
 
 package RT::Client::REST::Transaction;
-$RT::Client::REST::Transaction::VERSION = '0.60';
-use base 'RT::Client::REST::Object';
+$RT::Client::REST::Transaction::VERSION = '0.70';
+use parent 'RT::Client::REST::Object';
 
 use Params::Validate qw(:types);
-use RT::Client::REST::Object::Exception 0.03;
+use RT::Client::REST::Object::Exception;
 
 sub _attributes {{
     id  => {
@@ -143,7 +143,7 @@ RT::Client::REST::Transaction - transaction object representation.
 
 =head1 VERSION
 
-version 0.60
+version 0.70
 
 =head1 SYNOPSIS
 
@@ -257,11 +257,11 @@ L<RT::Client::REST::SearchResult>.
 
 =head1 AUTHOR
 
-Dmitri Tikhonov
+Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018 by Dmitri Tikhonov.
+This software is copyright (c) 2022, 2020 by Dmitri Tikhonov.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
